==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/QGpGuiTools/src/GuiGlobal.cpp <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2009-08-25
**  Copyright: 2009-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "GuiGlobal.h"

namespace QGpGuiTools {

  /*!
    \class GuiGlobal GuiGlobal.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  void setWidgetColor(QWidget * w, QColor c)
  {
    TRACE;
    QPalette palette;
    palette.setColor(QPalette::Window, c);
    w->setPalette(palette);
  }

  QColor widgetColor(QWidget * w)
  {
    TRACE;
    return w->palette().color(w->backgroundRole());
  }

} // namespace QGpGuiTools

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/QGpGuiTools/src/GuiGlobal.cpp <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2009-08-25
**  Copyright: 2009-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "GuiGlobal.h"

namespace QGpGuiTools {

  /*!
    \class GuiGlobal GuiGlobal.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  void setWidgetColor(QWidget * w, QColor c)
  {
    TRACE;
    QPalette palette;
    palette.setColor(QPalette::Window, c);
    w->setPalette(palette);
  }

  QColor widgetColor(QWidget * w)
  {
    TRACE;
    return w->palette().color(w->backgroundRole());
  }

  /*!
    Returns a sorted list of row indexes listed in \a l.
  */
  QList<int> sortedRows(const QModelIndexList& l)
  {
    TRACE;
    QModelIndex index;
    QList<int> rows;
    foreach(index, l) {
      rows.append(index.row());
    }
    std::sort(rows.begin(), rows.end());
    return rows;
  }

} // namespace QGpGuiTools
